pytilities.types

Package pytilities :: Package types |
[hide private]
[frames] | no frames]

# Package types

source code

Various types

Classes:

> - NumericType: Represents any numeric type.
> - NumberType: Represents any number type.
> - SequenceType: Represents any ordered sequence.
> - all types from the standard types package

Submodules | [hide private]
pytilities.types._numbertypemeta pytilities.types._numerictypemeta pytilities.types._sequencetypemeta pytilities.types.numbertype pytilities.types.numerictype pytilities.types.sequencetype

Variables | [hide private]
| StringTypes = ``(`<type 'str'>`,` <type 'unicode'>`)``
| __package__ = ``'``pytilities.types``'``